aboutsummaryrefslogtreecommitdiffstats
path: root/os/kernel/templates
diff options
context:
space:
mode:
Diffstat (limited to 'os/kernel/templates')
-rw-r--r--os/kernel/templates/chconf.h4
-rw-r--r--os/kernel/templates/chcore.c2
-rw-r--r--os/kernel/templates/chcore.h6
3 files changed, 6 insertions, 6 deletions
diff --git a/os/kernel/templates/chconf.h b/os/kernel/templates/chconf.h
index ae54d3edf..1e570c3cc 100644
--- a/os/kernel/templates/chconf.h
+++ b/os/kernel/templates/chconf.h
@@ -426,7 +426,7 @@
/**
* @brief Debug option, threads profiling.
- * @details If enabled then a field is added to the @p Thread structure that
+ * @details If enabled then a field is added to the @p thread_t structure that
* counts the system ticks occurred while executing the thread.
*
* @note The default is @p TRUE.
@@ -448,7 +448,7 @@
/**
* @brief Threads descriptor structure extension.
- * @details User fields added to the end of the @p Thread structure.
+ * @details User fields added to the end of the @p thread_t structure.
*/
#if !defined(THREAD_EXT_FIELDS) || defined(__DOXYGEN__)
#define THREAD_EXT_FIELDS \
diff --git a/os/kernel/templates/chcore.c b/os/kernel/templates/chcore.c
index 7639d9dd7..1f7db903c 100644
--- a/os/kernel/templates/chcore.c
+++ b/os/kernel/templates/chcore.c
@@ -128,7 +128,7 @@ void port_halt(void) {
* @param[in] ntp the thread to be switched in
* @param[in] otp the thread to be switched out
*/
-void port_switch(Thread *ntp, Thread *otp) {
+void port_switch(thread_t *ntp, thread_t *otp) {
}
/** @} */
diff --git a/os/kernel/templates/chcore.h b/os/kernel/templates/chcore.h
index f73b3b0c8..c993c724e 100644
--- a/os/kernel/templates/chcore.h
+++ b/os/kernel/templates/chcore.h
@@ -124,7 +124,7 @@ struct intctx {
};
/**
* @brief Platform dependent part of the @p Thread structure.
* @details This structure usually contains just the saved stack pointer
* defined as a pointer to a @p intctx structure.
*/
@@ -148,7 +148,7 @@ struct context {
/**
* @brief Computes the thread working area global size.
*/
-#define THD_WA_SIZE(n) STACK_ALIGN(sizeof(Thread) + \
+#define THD_WA_SIZE(n) STACK_ALIGN(sizeof(thread_t) + \
sizeof(struct intctx) + \
sizeof(struct extctx) + \
(n) + (PORT_INT_REQUIRED_STACK))
@@ -203,7 +203,7 @@ extern "C" {
void port_enable(void);
void port_wait_for_interrupt(void);
void port_halt(void);
- void port_switch(Thread *ntp, Thread *otp);
+ void port_switch(thread_t *ntp, thread_t *otp);
#ifdef __cplusplus
}
#endif
@@ -124,7 +124,7 @@ struct intctx {
};
/**
- * @brief Platform dependent part of the @p Thread structure.
+ * @brief Platform dependent part of the @p thread_t structure.
* @details This structure usually contains just the saved stack pointer
* defined as a pointer to a @p intctx structure.